@@ -17,6 +17,7 @@ class Watch:
         self.watch_list = []
         self.tracefunc_stack = []
         self.enable = False
+        self.stack_limit = 5
         self.set_lock = threading.Lock()
         self.tracefunc_lock = threading.Lock()
         self.restore()
@@ -33,7 +34,9 @@ class Watch:
                         alias=kwargs.get("alias", None),
                         default_alias=name,
                         callback=kwargs.get("callback", None),
-                        track=kwargs.get("track", ["variable", "object"])
+                        track=kwargs.get("track", ["variable", "object"]),
+                        when=kwargs.get("when", None),
+                        deepcopy=kwargs.get("deepcopy", False)
                     )
                 )
 
@@ -91,6 +94,9 @@ class Watch:
         if "file" in kwargs:
             self.file = kwargs["file"]
 
+        if "stack_limit" in kwargs:
+            self.stack_limit = kwargs["stack_limit"]
+
     def restore(self):
         self._callback = self._default_callback
         self.pdb = None
@@ -112,12 +118,13 @@ class Watch:
             for elem in self.watch_list:
                 changed, exist = elem.changed(frame)
                 if changed:
-                    if self.pdb:
-                        self.pdb_enable = True
-                    if elem._callback:
-                        elem._callback(frame, elem, (self._prev_funcname, self._prev_filename, self._prev_lineno))
-                    else:
-                        self._callback(frame, elem, (self._prev_funcname, self._prev_filename, self._prev_lineno))
+                    if not elem.when or elem.when(elem.obj):
+                        if self.pdb:
+                            self.pdb_enable = True
+                        if elem._callback:
+                            elem._callback(frame, elem, (self._prev_funcname, self._prev_filename, self._prev_lineno))
+                        else:
+                            self._callback(frame, elem, (self._prev_funcname, self._prev_filename, self._prev_lineno))
                     elem.update()
                 if not exist:
                     elem.exist = False
@@ -142,5 +149,5 @@ class Watch:
         return self.tracefunc
 
     def _default_callback(self, frame, elem, exec_info):
-        wp = WatchPrint(self.file)
+        wp = WatchPrint(self.file, stack_limit=self.stack_limit)
         wp(frame, elem, exec_info)
